/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.jmeter.testelement;

import org.apache.jmeter.engine.event.LoopIterationListener;

/**
 * Allow threads to perform startup and closedown if necessary
 *
 */
public interface ThreadListener {
    /**
     * Called for each thread before starting sampling.
     * WARNING: this is called before any Config test elements are processed,
     * so any properties they define will not have been merged in yet.
     * 
     * @see org.apache.jmeter.threads.JMeterThread#threadStarted()
     *
     */
    public void threadStarted();

    /**
     * Called for each thread after all samples have been processed.
     *
     * @see org.apache.jmeter.threads.JMeterThread#threadFinished(LoopIterationListener)
     *
     */
    public void threadFinished();

}